==> bootstrap4-dialog-4.1.0.tgz: package/README.md <==
Bootstrap-Dialog for Bootstrap 4.1

## Fully compatible with Bootstrap 4.1
## Includes size-extrawide full width display
## Includes all colour themes from Bootstrap 4


bootstrap-dialog
================

[![Latest release](https://img.shields.io/github/release/nakupanda/bootstrap3-dialog.svg)](https://github.com/nakupanda/bootstrap3-dialog/releases/latest)

Make use of Bootstrap Modal more monkey-friendly.

See live examples here: <a href="http://nakupanda.github.io/bootstrap3-dialog/">http://nakupanda.github.io/bootstrap3-dialog/</a>

Please note that this project is for <a href="http://getbootstrap.com/"><strong>Bootstrap 3</strong></a>.

Thanks for [akinoniku](https://github.com/akinoniku)'s suggestions on dialog appearance.

================

## Ask a question

It's recommended to provide online examples when asking questions or reporting bugs.
Fork this all-ready jsfiddle and start writing your example:
<a href="https://jsfiddle.net/o5k0eaws/1/">http://jsfiddle.net/o5k0eaws/1/</a>

================

## Use Guidances from contributors

<a href="https://gist.github.com/Genkilabs/bdcc5f62c5b46a8e0904">How to use bootstrap-dialog as Rails 4 confirm</a> - @[Genkilabs](https://github.com/Genkilabs)

================
## Reference to CDN

```
https://cdnjs.cloudflare.com/ajax/libs/bootstrap3-dialog/1.34.7/css/bootstrap-dialog.min.css
https://cdnjs.cloudflare.com/ajax/libs/bootstrap3-dialog/1.34.7/js/bootstrap-dialog.min.js
```
================

## Install using Bower

```
bower install bootstrap-dialog
```

Or

```
bower install bootstrap3-dialog
```

================

## Install using npm

```
npm install --save bootstrap3-dialog
```

================

## Build instructions:

Prepare:

```
npm install
```

Build:

```
gulp dist
```

================

Licensed under The MIT License.

==> bootstrap4-dialog-4.3.4.tgz: package/README.md <==
Version 4.3.4 - 1 May 2020

Bootstrap-Dialog for Bootstrap 4.3.1

## Fully compatible with Bootstrap 4.3.1
## Includes size-extrawide full width display
## Includes all colour themes from Bootstrap 4


bootstrap-dialog
================

[![Latest release](https://img.shields.io/github/release/nakupanda/bootstrap3-dialog.svg)](https://github.com/nakupanda/bootstrap3-dialog/releases/latest)

Make use of Bootstrap Modal more monkey-friendly.

See live examples here: <a href="http://nakupanda.github.io/bootstrap3-dialog/">http://nakupanda.github.io/bootstrap3-dialog/</a>

Please note that this project is for <a href="http://getbootstrap.com/"><strong>Bootstrap 3</strong></a>.

Thanks for [akinoniku](https://github.com/akinoniku)'s suggestions on dialog appearance.

================

## Ask a question

It's recommended to provide online examples when asking questions or reporting bugs.
Fork this all-ready jsfiddle and start writing your example:
<a href="https://jsfiddle.net/o5k0eaws/1/">http://jsfiddle.net/o5k0eaws/1/</a>

================

## Use Guidances from contributors

<a href="https://gist.github.com/Genkilabs/bdcc5f62c5b46a8e0904">How to use bootstrap-dialog as Rails 4 confirm</a> - @[Genkilabs](https://github.com/Genkilabs)

================
## Reference to CDN

```
https://cdnjs.cloudflare.com/ajax/libs/bootstrap3-dialog/1.34.7/css/bootstrap-dialog.min.css
https://cdnjs.cloudflare.com/ajax/libs/bootstrap3-dialog/1.34.7/js/bootstrap-dialog.min.js
```
================

## Install using Bower
```
bower install bootstrap4-dialog#https://github.com/GedMarc/bootstrap4-dialog.git
```

================

## Install using npm

```
npm install --save bootstrap4-dialog
```

================

## Build instructions:

Prepare:

```
npm install
```

Build:

```
gulp dist
```

================

Licensed under The MIT License.
